@@ -43,6 +43,9 @@ class GitHubBot:
                      1 Label Issues
                      2 Label Pull_requests
         """
+        cfgPath = os.path.split(__file__)[0]
+        if cfgPath != '':
+            confFilePath = cfgPath + "/" + confFilePath
         self.authFilePath = authFilePath
         self.confFilePath = confFilePath
         self.timeout = timeout
@@ -104,7 +107,6 @@ def cli1():
 @cli1.command()
 def web():
     """Simple program that label new issues on GitHub using webhooks."""
-    os.path.abspath(__file__)
     app.run()
 
 @click.group()
@@ -163,6 +165,7 @@ def getToken(authFileName, type):
     return token
 
 def loadLocalLabels(confFilePath):
+    print("Path to config file: " + confFilePath)
     config = configparser.ConfigParser()
     config.read(confFilePath)
     labelsSections = config.sections()
